import React, { useEffect, useMemo, useState } from "react";
import Taro, { useRouter } from "@tarojs/taro";
import "./index.scss";
import { View, Text, Input, Image } from "@tarojs/components";
import ContainerLayout from "../../../compents/container/index";
import radio from "../../../assets/radio.png";
import Layout from "../../../layout/index";
import request from "../../../util/request";
import groupby from "lodash.groupby";
import copy from '../../../assets/copy.png'

const house = props => {
  const router = useRouter();
  const [queryParams, setQueryParams] = useState({})
  const { houseId } = router.params;

  const [list, setList] = useState({});

  useEffect(() => {
    getList();
  }, [queryParams]);

  const getList = () => {
    request({
      url: "/taHousePerson",
      params: { houseId: houseId, pageSize: 9999 }
    }).then(res => {
      const { records, ...page } = res.data.data;
      console.log(groupby(records, item => item.orderId));
      setList(groupby(records, item => item.orderId));
      //   {
      //   const [date,_] = item.createDate.split('T')
      //   return date
      // }))
    });
  };

  const onCopy = value => {
    wx.setClipboardData({
      data: value,
      success(res) {}
    });
  };


  const handleDateChange = (e, item) => {
    const dt = e.detail.value
    if (!dt || dt == item.startDate) {
      return
    }

    Taro.showModal({
      title: '修改日期',
      content: `确认日期修改为: ${dt}`,
      success: e => {
        if (e.confirm) {
          request({
            url: `/taHouseSetting/${item.settingId}`,
            method: 'PUT',
            data: {
              startDate: dt
            }
          }).then(res => {
            Taro.showToast({
              title: '修改成功',
              icon: 'success',
            })

            // 触发页面刷新
            setQueryParams({})
          })
        }
      }
    })

  }

  return (
    <View className="household">
      <Layout>
        {/* <View className='household-text'>vjoaphepionvodashvoia</View> */}

        {Object.keys(list).map(item => {
          return (
            <View className="household-view">
              {/* {index + 1} */}
              <Text className="household-view-title">订单编号：{item}</Text>
              <ContainerLayout className="household-view-card">
                {list[item].map(x => {
                  return (
                    <View className="card-person">
                      <View style="flex: none" onClick={() => onCopy(x.name)}>
                        {x.name}
                        <Image className="household-view-card-icon" src={copy}></Image>
                      </View>
                      <View style="flex: none; margin-left: 16px" onClick={() => onCopy(x.phone)}>
                        {x.phone} 
                        <Image className="household-view-card-icon" src={copy}></Image>
                      </View>
                    </View>
                  );
                })}
                <View style="margin-top: 1em">
                  <picker
                    mode="date"
                    start="2021-03-01"
                    value={list[item][0].startDate}
                    onChange={e => handleDateChange(e, list[item][0])}
                  >
                    <View>
                      <Text>
                      {`入住时间：${list[item][0].startDate}`}
                      </Text>
                      <View style="display: inline-block; margin-left: .5em">
                        <mp-icon icon="pencil" size={16} color="#ffffff"></mp-icon>
                      </View>
                    </View>
                  </picker>
                </View>
                {list[item].length == 0 && "暂无入住人信息"}
              </ContainerLayout>
            </View>
          );
        })}
        {Object.keys(list).length === 0 && (
          <view style={{ textAlign: "center", paddingTop: 30 }}>
            暂无入住信息
          </view>
        )}
      </Layout>
    </View>
  );
};

export default house;
