import React, {
  useEffect,
  useMemo,
  useState,
  forwardRef,
  useImperativeHandle,
  useCallback
} from "react";
import Taro, { useDidShow } from "@tarojs/taro";
import { useSelector } from 'react-redux'
// import debounce from 'lodash.debounce'
import "./index.scss";
import { View, Text, Input, Image } from "@tarojs/components";
import ContainerLayout from "../../../compents/container/index";
import radio from "../../../assets/radio.png";
import request from "@/util/request";
import RecycleList from "@/compents/RecycleList";

let house = (props, ref) => {
  const user = useSelector(state => state.user)
  const defaultShop = user.defaultShop
  const [list, setList] = useState([]);
  const [radioHouse, setRadioHouse] = useState();
  const [width, setWidth] = useState();
  const [height, setHeight] = useState();
  const [queryParams, setQueryParams] = useState({ pageNum: 1, pageSize: 10, shopId: defaultShop });
  const [total, setTotal] = useState(0);

  useImperativeHandle(ref, () => ({
    // changeVal 就是暴露给父组件的方法
    getRefHouseList: () => {
      getHouseList();
    }
  }));

  const radioHouseState = useMemo(() => props.radioHouseState, [
    props.radioHouseState
  ]);
  

  const getHouseList = () => {
    if (!queryParams.shopId) return
    
    // console.log('---------->>>>', queryParams.shopId, queryParams.pageNum)

    request({
      url: "/taHouse",
      params: queryParams
    }).then(res => {
      const { records, ...page } = res.data.data;

      // console.log('-----page------>', page)

      if (page.current !== 1) {
        // console.log('-----page---1--->', page.current)
        setList(list.concat(records));
      } else {
        // console.log('-----page---2--->')
        // setList([]);  // 这句不能删, 部分机型上直接替换 list 不生效
        setList(records);
      }
      setTotal(page.total);
    });
  };

  const handleScrollBottom = e => {
    setQueryParams({
      ...queryParams,
      pageNum: queryParams.pageNum + 1
    });
  }

  const onShare = x => {
    Taro.navigateTo({ url: `/pages/share/index?houseId=${x.houseId}&&title=${x.title}` });
  };

  const handleDelete = x => {
    Taro.showModal({
      title: '删除',
      content: '确认删除当前房源?',
      success: res => {
        if (res.confirm) {
          request({
            url: `/taHouse/${x.houseId}`,
            method: 'DELETE'
          }).then(res => {
            setList(list.filter(t => t.houseId != x.houseId))
          });
        }
      }
    })
  }

  useEffect(() => {
    wx.setNavigationBarTitle({
      title: "民宿房源管理"
    });

    Taro.nextTick(() => {
      Taro.createSelectorQuery()
        .selectAll(".houselist")
        .boundingClientRect(res => {
          if (res) {
            setWidth(res[0].width);
            // setHeight(res[0].height)
          }
        })
        .exec();

      Taro.createSelectorQuery()
        .selectAll(".tab")
        .boundingClientRect(res => {
          let found = false;
          if (res) {
            for (let item of res) {
              if (item.height) {
                found = true;

                let h = Taro.getSystemInfoSync().safeArea.height - item.height - 50

                // 如果显示了下拉框，要去掉下拉框的高度
                if (user.shopList && user.shopList.length > 1) {
                  h -= 64
                }

                setHeight(h);
                break;
              }
            }
          }

          if (!found) {
            setHeight(500);
          }
        })
        .exec();
    });
  }, []);

  useDidShow(() => {
    if (queryParams.pageNum == 1) {
      getHouseList();
    } else {
      setQueryParams({
        ...queryParams,
        pageNum: 1
      });
    }
  });

  useEffect(() => {
    getHouseList();
  }, [queryParams]);

  useEffect(() => {
      setQueryParams({ ...queryParams, shopId: defaultShop, pageNum: 1 })
  }, [defaultShop])

  // useDidShow(() => {
  //   setQueryParams({ ...queryParams })
  // })
 
  return (
    <View className="houselist">
      {(!list || !list.length) && <View className="nodata"> 暂无数据</View>}
      <RecycleList
        height={height}
        width={width}
        list={list}
        total={total}
        dataKey="houseId"
        onScrollToLower={handleScrollBottom}
        renderItem={x => (
          <View className="houselist-view">
            {/* <Text className='houselist-view-title'>房源编号：{x.houseId}</Text> */}
            <ContainerLayout className="houselist-view-card">
              {radioHouseState && (
                <View
                  className="houselist-view-card-radio"
                  onClick={() => {
                    props.onChange(x), setRadioHouse(x);
                  }}
                >
                  {radioHouse?.houseId == x?.houseId && (
                    <Image
                      src={radio}
                      style={{ width: "30rpx", height: "20rpx" }}
                    ></Image>
                  )}
                </View>
              )}
              <View
                className="top"
                onClick={() => {
                  if (!radioHouseState)
                    Taro.navigateTo({
                      url: `/pages/house/index?houseId=${x.houseId}`
                    });
                }}
              >
                {x.title}
              </View>
              <View className="bottom">
                <View
                  className="bottom-btn"
                  onClick={() => {
                    if (!radioHouseState)
                      Taro.navigateTo({
                        url: `/pages/house/household/index?houseId=${x.houseId}`
                      });
                  }}
                >
                  查看入住人
                </View>
                <View className="bottom-btn" onClick={() => onShare(x)}>
                  分享链接
                </View>
                <View className="bottom-btn" onClick={() => handleDelete(x)}>
                  删除房源
                </View>
              </View>
            </ContainerLayout>
          </View>        
        )}
      />
    </View>
  );
};

house = forwardRef(house);
export default house;
