import React, { useEffect, useState } from "react";
import Taro from "@tarojs/taro";
import { View, Text, Image, Button } from "@tarojs/components";
import groupby from 'lodash.groupby'
import ContainerLayout from "../../compents/container/index";
import Divider from '../../compents/Divider'
import deleteicon from "../../assets/deleteicon.png";
import userRloe from "../../util/userRole";
import "./index.scss";
import { useSelector } from "react-redux";
import request from "../../util/request";

const ImageCard = props => {
  const { image, onDelete } = props;
  const user = useSelector(state => state.user);
  const [isopen, setIsOpen] = useState(false);

  return (
    <View
      className="recommend-view-card"
      style={{ height: !isopen ? "330rpx" : undefined, overflow: "hidden" ,background:'#fff', boxShadow:'6rpx 12rpx 0rpx #898989' }}
    >
      <Image
        className="recommend-view-img"
        mode="widthFix"
        src={image}
        onClick={() => setIsOpen(!isopen)}
        style={{zIndex:1}}
      ></Image>

      {userRloe.customer == user.role ? (
        undefined
      ) : (
        <View className="icon" onClick={() => onDelete()}>
          <Image
            className="icon-image"
            src={deleteicon}
          ></Image>
        </View>
      )}
    </View>
  );
};

const recommend = props => {
  const user = useSelector(state => state.user);

  const { value, houseId, ...prop } = props;

  // const [state, setState] = useState(1)
  const [list, setList] = useState({});
  const [id, setId] = useState();

  useEffect(() => {
    const lst = groupby(props.dataSource || [], 'groupName')
    // setList(props.dataSource || []);
    setList(lst)
  }, [props.dataSource]);

  const onClick = item => {
    if (user.role == userRloe.customer) {
      setId(item.surroundId);
    } else {
      Taro.showModal({
        title: "确定删除该图片吗？",
        content: "确定后，相关房东推荐会即时更新",
        cancelColor: "#d2d2d2",
        confirmColor: "#274191",
        success: function(res) {
          if (res.confirm) {
            console.log("用户点击确定");
            Taro.showLoading({ title: '删除中...' })
            request({
              url: `/taHouseSurround/${item.surroundId}`,
              method: "DELETE"
            }).then(res => {
              setList(list.filter(x => x.surroundId != item.surroundId));
              Taro.hideLoading()
            });
          } else if (res.cancel) {
            console.log("用户点击取消");
            Taro.hideLoading()
          }
        }
      });
    }
  };

  const listGroupKeys = Object.keys(list) || []

  return (
    <View className="recommend page">
      {user.role == userRloe.landlord && (
        <Button
          onClick={() =>
            Taro.navigateTo({ url: `/pages/material/index?houseId=${houseId}` })
          }
        >
          添加图片
        </Button>
      )}

      { 
        listGroupKeys.length == 0 ?
          (<View className="nodata"> 暂无数据</View>) :
          listGroupKeys.map(k => {
            const lst = list[k] || []

            return (
              <View className="page__hd">
                <View className="page__title" style="font-size: 1.6em">
                  <Divider>{lst[0].groupName}</Divider>
                </View>
                <View className="page__bd">
                {
                  lst.map(x => {
                    return (
                      <View className="recommend-view">
                        <ContainerLayout className="recommend-view-layout">
                          <ImageCard image={x.image} onDelete={() => onClick(x)} />
                        </ContainerLayout>
                      </View>
                    );
                  })
                }
                </View>
              </View>
            )
          })          
      }
    </View>
  );
};

export default recommend;
